==> haskell-text-printer-0.5.0.2-190-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-printer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-printer
version:              0.5.0.2
visibility:           public
id:                   text-printer-0.5.0.2-2H42zseTIl57x0cYLslJe8
key:                  text-printer-0.5.0.2-2H42zseTIl57x0cYLslJe8
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-printer
synopsis:             Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.

category:             Text
abi:                  375cbc85432f381fd384cb5903393cdc
exposed:              True
exposed-modules:
    Text.Printer Text.Printer.Fractional Text.Printer.Integral

import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-printer-0.5.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-printer-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-printer-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-printer
hs-libraries:         HStext-printer-0.5.0.2-2H42zseTIl57x0cYLslJe8
depends:
    base-4.18.2.1 bytestring-0.11.5.3 pretty-1.1.3.6 text-2.0.2
    text-latin1-0.3.1-3PAR5Knofz76T0GjiCOWDs

haddock-interfaces:
    /usr/share/doc/haskell-text-printer/html/text-printer.haddock

haddock-html:         /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-printer-0.5.0.2-191-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-printer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-printer
version:              0.5.0.2
visibility:           public
id:                   text-printer-0.5.0.2-K0VrJjE7oTG5FOFkZUnMXr
key:                  text-printer-0.5.0.2-K0VrJjE7oTG5FOFkZUnMXr
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-printer
synopsis:             Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.

category:             Text
abi:                  a2d3e4c174f7edf9b55050dc1280cc83
exposed:              True
exposed-modules:
    Text.Printer Text.Printer.Fractional Text.Printer.Integral

import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-printer-0.5.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-printer-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-printer-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-printer
hs-libraries:         HStext-printer-0.5.0.2-K0VrJjE7oTG5FOFkZUnMXr
depends:
    base-4.18.2.1 bytestring-0.11.5.3 pretty-1.1.3.6 text-2.0.2
    text-latin1-0.3.1-J81rCj0QIjR7NbtQznblwg

haddock-interfaces:
    /usr/share/doc/haskell-text-printer/html/text-printer.haddock

haddock-html:         /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
